@@ -343,6 +343,14 @@ sub run {
                     tag 'experimental-to-unstable-without-comment';
                 }
             }
+
+            my ($first_epoch) = ($first_version =~ /^([^:]+):/, '(none)');
+            my ($second_epoch) = ($second_version =~ /^([^:]+):/, '(none)');
+            if ($first_epoch and $second_epoch ne $first_epoch) {
+                tag 'epoch-change-without-comment',
+                  "$second_epoch -> $first_epoch"
+                  unless $entries[0]->Changes =~ /\bepoch\b/im;
+            }
         }
 
         # Some checks should only be done against the most recent
