@@ -370,6 +370,17 @@ sub run {
         }
     }
 
+    # Check Rules-Requires-Root
+    if (defined(my $r3 = $info->source_field('rules-requires-root'))) {
+        if ($r3 eq 'no') {
+            tag 'rules-does-not-require-root';
+        } elsif ($r3 eq 'binary-targets') {
+            tag 'rules-requires-root-explicitly';
+        }
+    } else {
+        tag 'rules-requires-root-implicitly';
+    }
+
     # find binary packages that Pre-Depend on multiarch-support without going
     # via ${misc:Pre-Depends}
     if ($info->source_field('build-depends')) {
