@@ -44,6 +44,10 @@ my $BAD_CONSTRUCT_IN_RULES
   = Lintian::Data->new('rules/rules-should-not-use', qr/\s*~~\s*/,
     sub { return qr/$_[1]/xs });
 
+my $BAD_MULTILINE_CONSTRUCT_IN_RULES
+  = Lintian::Data->new('rules/rules-should-not-use-multiline',
+    qr/\s*~~\s*/,sub { return qr/$_[1]/xsm });
+
 # Certain build tools must be listed in Build-Depends even if there are no
 # arch-specific packages because they're required in order to run the clean
 # rule.  (See Policy 7.6.)  The following is a list of package dependencies;
@@ -208,6 +212,20 @@ sub run {
             }
         }
 
+        if (/^\s*(?:export\s+)?DEB_BUILD_OPTIONS\s*:?=/ && keys(%seen) == 0) {
+            tag 'debian-rules-sets-DEB_BUILD_OPTIONS', "line $.";
+        }
+
+        if (
+            /^
+                \s*(?:export\s+)?
+                (DEB_(?:HOST|BUILD|TARGET)_(?:ARCH|MULTIARCH|GNU)[A-Z_]*)\s*:?=
+            /x
+            && keys(%seen) == 0
+          ) {
+            tag 'debian-rules-sets-dpkg-architecture-variable', "$1 (line $.)";
+        }
+
         # check generic problem
         foreach my $bad_construct ($BAD_CONSTRUCT_IN_RULES->all) {
             my $badregex = $BAD_CONSTRUCT_IN_RULES->value($bad_construct);
@@ -440,6 +458,17 @@ sub run {
         }
     }
 
+    $rules_fd = $rules->open;
+    my $sfd = Lintian::SlidingWindow->new($rules_fd);
+    my $block;
+    while ($block = $sfd->readwindow) {
+        foreach my $tag ($BAD_MULTILINE_CONSTRUCT_IN_RULES->all) {
+            my $regex = $BAD_MULTILINE_CONSTRUCT_IN_RULES->value($tag);
+            tag $tag if $block =~ m/$regex/;
+        }
+    }
+    close($rules_fd);
+
     return;
 }
 
